inet_aton

Function inet_aton 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn inet_aton( cp: *const c_char, inp: *mut in_addr, ) -> c_int
Non-POSIX, see https://www.man7.org/linux/man-pages/man3/inet_aton.3.html.

Converts the Internet host address cp from the IPv4 numbers-and-dots notation into binary form (in network byte order) and stores it in the structure that inp points to.