inet_lnaof

Function inet_lnaof 

#[unsafe(no_mangle)]
pub extern "C" fn inet_lnaof(in: in_addr) -> in_addr_t
๐Ÿ‘ŽDeprecated
See https://pubs.opengroup.org/onlinepubs/7908799/xns/inet_lnaof.html.

Takes an Internet host address specified by in and extracts the local network address part, in host byte order.

Deprecation

The inet_lnaof() function was specified in Networking Services Issue 5, but not in the Open Group Base Specifications Issue 6 and later.