inet_netof

Function inet_netof 

#[unsafe(no_mangle)]
pub extern "C" fn inet_netof(in: in_addr) -> in_addr_t
๐Ÿ‘ŽDeprecated
See https://pubs.opengroup.org/onlinepubs/7908799/xns/inet_netof.html.

Takes an Internet host address specified by in and extracts the network number part, in host byte order.

Deprecation

The inet_netof() function was specified in Networking Services Issue 5, but not in the Open Group Base Specifications Issue 6 and later.