inet_ntoa

Function inet_ntoa 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn inet_ntoa(in: in_addr) -> *mut c_char
๐Ÿ‘ŽDeprecated
See https://pubs.opengroup.org/onlinepubs/9799919799/functions/inet_addr.html.

Converts the Internet host address specified by in to a string in the Internet standard dot notation.

Deprecation

The inet_ntoa() function was marked obsolescent in the Open Group Base Specifications Issue 8.

Applications should prefer inet_ntop() over inet_ntoa() as it supports multiple address families and is thread-safe.