#[unsafe(no_mangle)]pub extern "C" fn inet_makeaddr(
net: in_addr_t,
lna: in_addr_t,
) -> in_addr๐Deprecated
See https://pubs.opengroup.org/onlinepubs/7908799/xns/inet_makeaddr.html.
Takes the Internet network number specified by net and the local network
address specified by lna, both in host byte order, and constructs an
Internet address from them.
Deprecation
The inet_makeaddr() function was specified in Networking Services Issue
5, but not in the Open Group Base Specifications Issue 6 and later.