#[unsafe(no_mangle)]pub unsafe extern "C" fn inet_network(cp: *const c_char) -> in_addr_t๐Deprecated
See https://pubs.opengroup.org/onlinepubs/7908799/xns/inet_network.html.
Converts the string pointed to by cp, in the Internet standard dot
notation, to an integer value suitable for use as an Internet network
number.
Deprecation
The inet_network() function was specified in Networking Services Issue 5,
but not in the Open Group Base Specifications Issue 6 and later.